@@ -11,10 +11,10 @@ use File::Path qw(mkpath);
 
 use AI::Pathfinding::OptimizeMultiple::Scan;
 
-use PDL;
-use PDL::IO::FastRaw;
+use PDL (qw( pdl ));
+use PDL::IO::FastRaw (qw( readfraw writefraw ));
 
-our $VERSION = '0.0.8';
+our $VERSION = '0.0.9';
 
 has start_board => (isa => 'Int', is => 'ro', required => 1);
 has num_boards => (isa => 'Int', is => 'ro', required => 1);
@@ -27,6 +27,16 @@ has selected_scans => (isa => 'ArrayRef', is => 'ro', required => 1,
     lazy => 1,
 );
 
+has _scan_ids_to_indexes => (isa => 'HashRef[Int]', is => 'ro',
+    lazy => 1,
+    default => sub {
+        my ($self) = @_;
+
+        my $scan_ids = $self->get_scan_ids_aref;
+        return +{ map { $scan_ids->[$_] => $_} 0 .. $#$scan_ids };
+    },
+);
+
 sub _slurp
 {
     my $filename = shift;
@@ -234,14 +244,21 @@ sub _is_scan_suitable
     );
 }
 
+sub _get_scans_registry_file_path
+{
+    return "scans.txt";
+}
+
 sub _get_all_scans_list_from_file
 {
     my $self = shift;
 
     my @scans;
 
-    open my $scans_fh, "<", "scans.txt"
-        or die "Could not open 'scans.txt' - $!.";
+    my $scans_fn = $self->_get_scans_registry_file_path;
+
+    open my $scans_fh, "<", $scans_fn
+        or die "Could not open '$scans_fn' - $!.";
     while (my $line = <$scans_fh>)
     {
         chomp($line);
@@ -295,16 +312,28 @@ sub _calc_selected_scan_list
         )
 }
 
+sub _get_next_id_file_path
+{
+    return "next-id.txt";
+}
+
 sub get_next_id
 {
+    my ($self) = @_;
+
     my $id;
 
-    open my $in, "<", "next-id.txt";
+    my $fn = $self->_get_next_id_file_path;
+
+    use autodie;
+
+    open my $in, "<", $fn;
     $id = <$in>;
     chomp($id);
     close($in);
-    open my $out, ">", "next-id.txt";
-    print $out ($id+1);
+
+    open my $out, ">", $fn;
+    print {$out} ($id+1);
     close($out);
 
     return $id;
@@ -312,8 +341,14 @@ sub get_next_id
 
 sub get_prev_scans
 {
+    my ($self) = @_;
+
     my @prev_scans;
-    open my $in, "<", "scans.txt";
+
+    my $scans_fn = $self->_get_scans_registry_file_path;
+
+    open my $in, "<", $scans_fn
+        or die "Could not open '$scans_fn' - $!.";;
     while (my $line = <$in>)
     {
         chomp($line);
@@ -334,14 +369,26 @@ sub _get_scan_cmd_line
     my $max_board = $args->{'max'} || 32_000;
     my $id = $args->{'id'};
     my $argv = $args->{'argv'};
+    my @fc_num =
+        (exists($args->{'freecells_num'})
+            ?  ("--freecells-num" , $args->{'freecells_num'})
+            : ()
+        );
+    my @variant =
+        (exists($args->{'variant'})
+            ? ("--variant", $args->{'variant'})
+            : ()
+        );
 
     return
     [
         qw(freecell-solver-fc-pro-range-solve),
         $min_board, $max_board, "20",
+        @variant,
         qw(--total-iterations-limit 100000 --binary-output-to),
         "data/$id.data.bin",
         @$argv,
+        @fc_num,
     ];
 }
 
@@ -380,6 +427,26 @@ sub time_scan
     close($fc_pro_out);
 }
 
+sub get_scan_ids_aref
+{
+    my $self = shift;
+
+    return [map { $_->id() } @{ $self->selected_scans }];
+}
+
+sub lookup_scan_idx_based_on_id
+{
+    my ($self, $scan_id) = @_;
+
+    my $idx = $self->_scan_ids_to_indexes->{$scan_id};
+    if (!defined($idx))
+    {
+        die "Index '$idx' does not exist!";
+    }
+
+    return $idx;
+}
+
 1;
 
 __END__
@@ -394,7 +461,7 @@ AI::Pathfinding::OptimizeMultiple::DataInputObj - handle the data input.
 
 =head1 VERSION
 
-version 0.0.8
+version 0.0.9
 
 =head1 SUBROUTINES/METHODS
 
@@ -430,6 +497,15 @@ The index of the board to start from.
 
 Times a new scan.
 
+=head2 $self->get_scan_ids_aref()
+
+Get an array reference of the scan IDs.
+
+=head2 my $idx = $self->lookup_scan_idx_based_on_id($scan_id)
+
+$scan_id is a string and lookup_scan_idx_based_on_id() looks up its index
+in the scans.
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2010 Shlomi Fish
